@@ -199,11 +199,15 @@ class Window(QtGui.QMainWindow):
     def saveAsFile(self):
         filename = QtGui.QFileDialog.getSaveFileName(self,
                         "KhtEditor -- Save File As",
-                        self.editor.filename, "Python files (*.py *.pyw)")
+                        self.editor.filename, u'Python file(*.py);;'  
+                                            + u'Text file(*.txt);;' 
+                                            + u'C File(*.c);;' 
+                                            + u'C++ File(*.cpp)')
         if not filename.isEmpty():
             self.editor.filename = filename
             self.setWindowTitle(QtCore.QFileInfo(filename).fileName())
             self.fileSave()
+        return filename
 
 
     def openFile(self, path=QtCore.QString()):
@@ -267,7 +271,7 @@ class Window(QtGui.QMainWindow):
         #self.language = self.detectLanguage(filename)
         self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator,True)
         QtGui.QApplication.processEvents()
-        self.highlighter = pygment_highlighter.Highlighter(self.editor.document(),str(filename))
+        self.highlighter = pygments_highlighter.Highlighter(self.editor.document(),str(filename))
         QtGui.QApplication.processEvents()
         self.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator,False)
     
